from oslui.prompts.base import BasePrompt, DataCell, RoleType
from oslui.prompts.chat import ChatPrompt, ChatInput, chat_user_cell, chat_assistant_cell
from oslui.prompts.translate import TranslatePrompt, TranslateInput
from oslui.prompts.classifier import ClassifierPrompt, ClassifierInput
from oslui.prompts.debug import DebugPrompt, DebugInput
